# ezmsg.zmq

Zero-MQ pub/sub units for ezmsg

## Installation
`pip install ezmsg-sigproc`

## Dependencies
* `ezmsg`
* `pyzmq`

## Setup (Development)
1. Install `ezmsg` either using `pip install ezmsg` or set up the repo for development as described in the `ezmsg` readme.
2. `cd` to this directory (`ezmsg-zmq`) and run `pip install -e .`
3. Signal processing modules are available under `import ezmsg.zmq`